#
# spec file for package python-xlrd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-xlrd
Version:        2.0.1
Release:        2.3
Summary:        Python module for extracting data from .xls Excel spreadsheet files
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://www.python-excel.org/
Source:         https://github.com/python-excel/xlrd/archive/refs/tags/%{version}.tar.gz#/xlread-%{version}-gh.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A library for reading data and formatting information from Excel files
in the historical .xls format.

%prep
%setup -q -n xlrd-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
mv %{buildroot}%{_bindir}/runxlrd.py %{buildroot}%{_bindir}/runxlrd
%python_clone -a %{buildroot}%{_bindir}/runxlrd

%post
%python_install_alternative runxlrd

%postun
%python_uninstall_alternative runxlrd

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/runxlrd
%{python_sitelib}/xlrd
%{python_sitelib}/xlrd-%{version}*-info

%changelog
* Wed Sep 25 2024 Guang Yee <gyee@suse.com>
- Enable sle15_python_module_pythons.
* Fri Apr 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * Remove support for anything other than .xls files.
  * Remove support for psyco.
  * Change the default encoding used when no CODEPAGE record can be
    found from ascii to iso-8859-1.
  * Add support for iterating over `xlrd.book.Book` objects.
  * Add support for item access from `xlrd.book.Book`
    objects, where integer indices and string sheet names are
    supported.
  * Non-unicode spaces are now stripped from the "last author"
    information.
  * Workbook corruption errors can now be ignored using the
    ignore_workbook_corruption option to `xlrd.open_workbook`.
  * Handle WRITEACCESS records with invalid trailing characters.
  * Officially support Python 3.8 and 3.9.
* Fri May 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Replace nose with python
* Fri May 15 2020 pgajdos@suse.com
- %%python3_only -> %%python_alternative
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 1.2.0
  * Added support for Python 3.7.
  * Added optional support for defusedxml to help mitigate exploits.
  * Automatically convert ``~`` in file paths to the current user's home
    directory.
  * Removed ``examples`` directory from the installed package. They are still
    available in the source distribution.
  * Fixed ``time.clock()`` deprecation warning.
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary again.
* Wed Jun 13 2018 toddrme2178@gmail.com
- Update to 1.1.0
  * Fix for parsing of merged cells containing a single cell reference in xlsx
    files.
  * Fix for "invalid literal for int() with base 10: 'true'" when reading some
    xlsx files.
  * Make xldate_as_datetime available to import direct from xlrd.
  * Build universal wheels.
  * Sphinx documentation.
  * Document the problem with XML vulnerabilities in xlsx files and mitigation
    measures.
  * Fix :class:`NameError` on ``has_defaults is not defined``.
  * Some whitespace and code style tweaks.
  * Make example in README compatible with both Python 2 and 3.
  * Add default value for cells containing errors that causeed parsing of some
    xlsx files to fail.
  * Add Python 3.6 to the list of supported Python versions, drop 3.3 and 2.6.
  * Use generator expressions to avoid unnecessary lists in memory.
  * Document unicode encoding used in Excel files from Excel 97 onwards.
  * Report hyperlink errors in R1C1 syntax.
* Wed May  3 2017 toddrme2178@gmail.com
- Fix license
- Executable is python version independent so make it python3-only.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Source url must be https.
* Tue Apr 18 2017 toddrme2178@gmail.com
- Update to 1.0.0
  * Official support, such as it is, is now for 2.6, 2.7, 3.3+
  * Fixes a bug in looking up non-lowercase sheet filenames by
    ensuring that the sheet targets are transformed the same way
    as the component_names dict keys.
  * Fixes a bug for ragged_rows=False when merged cells increases
    the number of columns in the sheet. This requires all rows
    to be extended to ensure equal row lengths that match the
    number of columns in the sheet.
  * Fixes to enable reading of SAP-generated .xls files.
  * support BIFF4 files with missing FORMAT records.
  * support files with missing WINDOW2 record.
  * Empty cells are now always unicode strings, they were a
    bytestring on Python 2 and a unicode string on Python 3.
  * Fix for <cell> inlineStr attribute without <si> child.
  * Fix for a zoom of None causing problems on Python 3.
  * Fix parsing of bad dimensions.
  * Fix xlsx sheet to comments relationship.
- Implement single-spec version.
* Thu Oct 29 2015 scorot@free.fr
- Update to 0.9.4
  * No changelog available
* Tue Apr 30 2013 toddrme2178@gmail.com
- Remove unnecessary .py extension from executable
- Fix python2/python3 executable name conflict
* Tue Apr 16 2013 jfunk@funktronics.ca
- Update to 0.9.2:
  - Bug fixes
- Changes from 0.9.1:
  * Removed support for Python < 2.6
  * Bug fixes
- Changes from 0.9.0:
  * Python3 support
  * Expanded tests
  * Bug fixes
- Spec cleanup
* Tue Nov 13 2012 jfunk@funktronics.ca
- Update to 0.8.0
  * This release finally lands the support for both .xls and .xlsx files. Many
    thanks to John Machin for all his work on making this happen. Opening of
    .xlsx files is seamless, just use xlrd as you did before and it all should
    "just work".
  * xlrd 0.8.0 is also the first release that that targets Python 2.6 and 2.7,
    but no Python 3 just yet. Python 2.5 and below may work but are not
    supported. If you need to use Python 2.5 or earlier, please stick to xlrd
    0.7.x.
* Fri Apr 27 2012 jfunk@funktronics.ca
- Update to 0.7.7
  * Changelog information unavailable
* Fri Apr  6 2012 jfunk@funktronics.ca
- Update to 0.7.6:
  * Changelog information unavailable
* Tue Feb 28 2012 jfunk@funktronics.ca
- Update to 0.7.3
* Tue Feb 21 2012 jfunk@funktronics.ca
- Update to 0.7.2
- Update spec for current conventions
* Wed May 12 2010 jfunk@funktronics.ca
- Initial release
